######################################################################################################
#   Yearly activity stats                                                                            #
#                                                                                                    #
#   Filename:  training2013.r                                                                        #
#                                                                                                    #
#   Description: some stats about the activities logged in the file "2012.csv"                       #
#                                                                                                    #
#                                                                                                    #
#   History:                                                                                         #
#   27/06/2013   Lorenzo Clementi    v0.1  Creation                                                  #
#                                                                                                    #
#                                                                                                    #
######################################################################################################
library("graphics")

inFile <- "2013.csv"

print(paste ("Reading: ", inFile))

rbPal <- colorRampPalette(c('red','blue','green', 'brown'))

maxx <- length(date)
dm <- read.csv2(inFile, header=TRUE, dec=".", colClasses=c("character", "numeric","numeric","numeric","character","character"))
dm$date <- as.Date(dm$date, "%Y/%m/%d")

type <- as.vector(dm$type)
type <- replace(type, type == " b", "3")
type <- replace(type, type == " m", "2")
type <- replace(type, type == " r", "1")
type <- replace(type, type == " p", "0")
dm$typeN <- as.numeric(type)

dm$type <- rbPal(4)[as.numeric(cut(dm$typeN,breaks=4))]
start <- as.Date("2013/1/1", "%Y/%m/%d")
end <- as.Date("2013/12/31", "%Y/%m/%d")
xrange <- c(start, end)


pngFile <- "duration.png"
png(pngFile, width=1080, height=576, units="px", pointsize=14.5, type="cairo", antialias="gray")

par(mar=c(7.1,4.1,3.1,3.1), cex=1.5)
yrange <- c(0, max(dm$duration))
maxy <- max(dm$duration)
plot(yrange ~ xrange, dm, xaxt = "n", type = "n", ylab="duration [h]", xlab="", axes=FALSE, main="Duration of the activity")
points(dm$duration ~ date, dm, col=dm$type, pch=19, cex=1.5, bg="white")
#points(as.vector(23) ~ as.Date("2012/07/03", "%Y/%m/%d"), col="violet", pch=19, cex=1.6, bg="white")
axis(1, at=seq(as.Date("2013/01/01"), as.Date("2013/12/31"), length.out=12), labels=as.vector(c("Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dic")), format(dm$date, "%d/%m"), padj=0.5, tck=0, las=2, pos=0)
axis(2, at=seq(0, maxy, length.out=4), labels=round(c(0,maxy/60*0.33, maxy/60*0.66,maxy/60), digits=1))
#grid(nx=NA, ny=NULL, lwd=1.2,col = "black") # grid only in y-direction
abline(h=seq(0, maxy, length.out=4), lwd=1.2,col = "black",lty="dotted")
dev.off()
print(paste("Graph written to: ", pngFile))

pngFile <- "height.png"
png(pngFile, width=1080, height=576, units="px", pointsize=14.5, type="cairo", antialias="gray")

par(mar=c(7.1,4.1,3.1,3.1), cex=1.5)
yrange <- c(0, max(dm$height))
plot(yrange ~ xrange, dm, xaxt = "n", type = "n", ylab="elevation gain [m]", xlab="", axes=FALSE, main="Elevation gain in meters")
points(dm$height ~ date, dm, col=dm$type, pch=19, cex=1.5, bg="white")
axis(1, at=seq(as.Date("2013/01/01"), as.Date("2013/12/31"), length.out=12), labels=as.vector(c("Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dic")), format(dm$date, "%d/%m"), padj=0.5, tck=0, las=2, pos=0)
axis(2)
grid(nx=NA, ny=NULL, lwd=1.2,col = "black") # grid only in y-direction
dev.off()
print(paste("Graph written to: ", pngFile))


pngFile <- "height-duration.png"
png(pngFile, width=1080, height=576, units="px", pointsize=14.5, type="cairo", antialias="gray")

par(mar=c(7.1,4.1,3.1,3.1), cex=1.5)
xrange <- c(0, max(dm$duration))
yrange <- c(0, max(dm$height))
plot(yrange ~ xrange, dm, xaxt = "n", xlab="duration [h]", ylab="elevation gain [m]", type = "n",axes=FALSE, main="Elevation gain against training duration")
points(dm$height ~ dm$duration, dm, col=dm$type, pch=19, cex=1.5, bg="white")
axis(2)
axis(1, at=seq(0, maxy, length.out=4), labels=round(c(0,maxy/60*0.33, maxy/60*0.66,maxy/60), digits=1), pos=0)
grid(nx=NA, ny=NULL, lwd=1.2,col = "black") # grid only in y-direction
dev.off()
print(paste("Graph written to: ", pngFile))

pngFile <- "height-distance.png"
png(pngFile, width=1080, height=576, units="px", pointsize=14.5, type="cairo", antialias="gray")

par(mar=c(7.1,4.1,3.1,3.1), cex=1.5)	     
dm$distance <- as.numeric(dm$distance)
yrange <- c(0, max(dm$height))
xrange <- c(0, max(dm$distance))
maxy <- max(dm$distance)
plot(yrange ~ xrange, dm, type="n", xlab="distance [km]", ylab="elevation gain [m]", axes=F, main="Elevation difference against distance covered")
points(dm$height ~ dm$distance, dm, col=dm$type, pch=19, cex=1.5, bg="white")
axis(1, pos=0)
axis(2)
grid(nx=NA, ny=NULL, lwd=1.2,col = "black") # grid only in y-direction
dev.off()
print(paste("Graph written to: ", pngFile))




print(paste("Total number of activities:", length(dm$duration)))
print(paste("Average duration in minutes:", round(mean(dm$duration), digits=2), "and in hours:", round(mean(dm$duration)/60, digits=2)))
print(paste("Average elevation gain in meters:", round(mean(dm$height), digits=2)))
print(paste("Average distance in meters:", round(mean(dm$distance), digits=2)))
print(paste("Total elevation gain in meters:", sum(dm$height)))
print(paste("Total distance in kilometers:", sum(as.numeric(dm$distance), na.rm=TRUE)))
print(paste("Correlation coefficient between duration of the training and elevation gain:", round(cor(dm$duration, dm$height), digits=2)))

indexesRunning <- which(dm$typeN == 1)
print(paste("Total postive running elevation gain in meters:", sum(dm$height[indexesRunning])))
print(paste("Total running distance in kilometers:", sum(as.numeric(dm$distance[indexesRunning]), na.rm=TRUE)))

indexesSki <- which(dm$typeN == 0)
print(paste("Total postive ski elevation gain in meters:", sum(dm$height[indexesSki])))
print(paste("Total ski distance in kilometers:", sum(as.numeric(dm$distance[indexesSki]), na.rm=TRUE)))

indexesMix <- which(dm$typeN == 2)
print(paste("Total postive mixed elevation gain in meters:", sum(dm$height[indexesMix])))
print(paste("Total mixed distance in kilometers:", sum(as.numeric(dm$distance[indexesMix]), na.rm=TRUE)))

indexesBike <- which(dm$typeN == 3)
print(paste("Total postive bike elevation gain in meters:", sum(dm$height[indexesBike])))
print(paste("Total bike distance in kilometers:", sum(as.numeric(dm$distance[indexesBike]), na.rm=TRUE)))

pngFile <- "actTypeHeight.png"
png(pngFile, width=800, height=800, units="px", pointsize=14.5, type="cairo", antialias="gray")

actTypeHeight <- as.vector(c(sum(dm$height[indexesRunning]), sum(dm$height[indexesSki]), sum(dm$height[indexesMix]), sum(dm$height[indexesBike])))
rbPal <- colorRampPalette(c('blue','red','green', 'brown'))
barplot(actTypeHeight, names.arg=c("Running", "Ski", "Mixed", "Bike"), main="Elevation gain according to activity type",col=rbPal(4), ylab="[m]")
dev.off()
print(paste("Graph written to: ", pngFile))

pngFile <- "actTypeDist.png"
png(pngFile, width=800, height=800, units="px", pointsize=14.5, type="cairo", antialias="gray")

actTypeDistance <- as.vector(c(sum(dm$distance[indexesRunning]), sum(dm$distance[indexesSki]), sum(dm$distance[indexesMix]), sum(dm$distance[indexesBike])))
rbPal <- colorRampPalette(c('blue','red','green', 'brown'))
barplot(actTypeDistance, names.arg=c("Running", "Ski", "Mixed", "Bike"), main="Distance covered according to activity type",col=rbPal(4), ylab="[km]")
dev.off()
print(paste("Graph written to: ", pngFile))


pngFile <- "cumulative.png"
png(pngFile, width=1080, height=576, units="px", pointsize=14.5, type="cairo", antialias="gray")
par(mar=c(7.1,4.1,3.1,3.1), cex=1.5)
plot(c(0, cumsum(dm$height)/1000) ~ c(0, cumsum(dm$distance)), dm, xaxt = "n", lwd=4, xlab="distance [km]",axes=F, ylab="elevation gain [km]", type = "l",main="Cumulative elevation gain against distance",xlim=c(0,max(cumsum(dm$distance))))
polygon(c(0, cumsum(dm$distance), max(cumsum(dm$distance))),c(0, cumsum(dm$height)/1000, 0),  col="gray")
axis(1, pos=0)
axis(2)
dev.off()
print(paste("Graph written to: ", pngFile))


print("Number of activities per month:")
print(aggregate(dm$height,by=list(substr(dm$date,1,7)),length))
print("Elevation in meters by month:")
print(aggregate(dm$height,by=list(substr(dm$date,1,7)),sum))

#print("Input data was:")
#print(dm)

print("End, all done! See you next year, now go out and run!")
